#ifndef NON_MODAL_FILE_DIALOG_H
#define NON_MODAL_FILE_DIALOG_H

class CNonModalFileDialogParent
{
public:
   //---------------------------------------------------------
   // The class that creates a CNonModalFileDialog must
   // provide these functions in order to process
   // the CFileDialog's information.
   //
   // If a pointer to the CNonModalFileDialog is maintained
   // by the parent, it should be set to NULL in
   // these methods since the thread exits immediately
   // after invoking these methods.
   //
   // Maintaining a pointer to the CNonModalFileDialog is
   // not strictly necessary since the NonModalFileDialog
   // cleans up after itself. (Actually, the OS cleans
   // it up but that is not germaine, here.) However,
   // multiple instances will lead to multiple,
   // independent FileDialogs all sharing a single set of
   // Parent-implemented methods.
   //
   // The handler to display a NonModalFileDialog might
   // look like:
   //      if (_pFileDialog == NULL) {
   //         _pFileDialog = new CNonModalFileDialog (...);}
   //      else {
   //         _pFileDialog->Show ();
   //---------------------------------------------------------
	virtual void OnFileDialogOK (CFileDialog *dlg) = 0;
	virtual void OnFileDialogCANCEL (void) = 0;
};

class CNonModalFileDialog : public CWinThread
{
public:
   //-----------------------------------------------
   // Looks a lot like the CFileDialog constructor.
   // Should probably be expanded to permit setting
   // all of the OPENFILENAME structure's members.
   //-----------------------------------------------
	CNonModalFileDialog(
      CNonModalFileDialogParent *myParent,
      bool bMultiSelectable = false,
      LPCSTR lpszPath = NULL,
		bool bOpenFileDialog = true,
		LPCSTR lpszDefExt = NULL,
		LPCTSTR lpszFileName = NULL,
		DWORD dwFlags = OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT,
		LPCTSTR lpszFilter = NULL,
		CWnd* pParentWnd = NULL);
   //-------------------------------------------------------------------
   // myParent:          The caller of this instance. Will process
   //                    the eventual OK and CANCEL from the FileDialog.
   // bMultiSelectable:  Will the FileDialog be able to select
   //                    multiple files?
   // lpszPath:          The directory to browse initially.
   // bOpenFileDialog:   When true, the FileDialog is for opening files.
   //                    When false, FileDialog operates as SaveAs.
   // lpszDefExt:        In SaveAs mode, if user fails to append an
   //                    extension, this one will be provided to him at
   //                    no cost.
   // lpszFileName:      The name to display in the File Name box.
   //                    NULL leads to a blank field.
   // dwFlags:           See the CFileDialog documentation for this.
   // lpszFileter:       Again, this is best described in CFileDialog.
   // pParentWnd:        The parent window for the FileDialog.
   //-------------------------------------------------------------------

   ~CNonModalFileDialog ();
	
   void Show (void);
   virtual BOOL InitInstance();

private:
   bool        _multiSelectable;
   CString     _lpszPath;
	bool        _bOpenFileDialog;
	CString     _lpszDefExt;
	CString     _lpszFileName;
	DWORD       _dwFlags;
	CString     _lpszFilter;
	CWnd*       _pParentWnd;

	CFrameWnd   wind;
	static bool registeredDummy;

	CNonModalFileDialogParent *_myParent;
	CFileDialog               *_dlg;
};


#endif